@@ -303,15 +303,16 @@ class BaseBot:
             if not has_cooldown_bypass_permission:
                 update_command_last_execute(msg.channel_name, cmd.fullname)
         except InvalidArgumentsError as e:
-            await self._send_cmd_help(msg, cmd, e)
+            await self._send_cmd_help(msg, cmd.get_sub_cmd(msg.args)[0], e)
         else:
             forward_event(Event.on_after_command_execute, msg, cmd, channel=msg.channel_name)
 
     async def _send_cmd_help(self, msg: Message, cmd: Command, exc: InvalidArgumentsError):
+        cmd_chain_str = ' '.join((c.name for c in cmd.parent_chain()))
         await msg.reply(translate(
             'send_command_help_message',
             reason=exc.reason,
-            cmd_fullname=cmd.fullname,
+            cmd_fullname=cmd_chain_str,
             command_prefix=get_command_prefix(),
             cmd_syntax=(cmd.syntax or '')
         ))
